<?php

$sessionId = array_key_exists("session", $_REQUEST) ? $_REQUEST["session"] : $_REQUEST["SESSION"];
$mapName = array_key_exists("mapname", $_REQUEST) ? $_REQUEST["mapname"] : $_REQUEST["MAPNAME"];

?>
<html>
    <head>
        <title>pgRouting Example</title>
        <style type="text/css">
        #status { color: red; }
        </style>
        <script type="text/javascript" src="common.js"></script>
        <script type="text/javascript">
        
        function updateStatus(msg) {
            document.getElementById("status").innerHTML = msg;
        }
        
        function checkParameters() {
            //Do any pre-submission checks. Return true if we're good to go. Return false otherwise
            var srcId = document.getElementById("SOURCE_ID").value;
            var dstId = document.getElementById("TARGET_ID").value;
            if (srcId === "" || dstId === "") {
                alert("Missing required source or target ID");
                return false;
            }
            return true;
        }
        
        var timer = null;
        var selectedRoads = 0;
        
        //Function variable to store the original OnSelectionChanged
        var origOnSelectedFeatureChanged = null;

        //Our custom selection handler
        function onAjaxViewerSelectionChanged()
        {
            //This is important. We don't want to replace the original function, rather
            //we want to attach our code into the execution sequence. So we call the original
            //function first.
            origOnSelectedFeatureChanged();

            var viewer = getViewerInstance();

            //For this example, Roads is the only layer, so we are safe to assume anything selected is from
            //this layer
            selectedRoads = viewer.GetMapFrame().GetSelectedCount();
            updateStatus(selectedRoads + " roads selected");
        }
        
        window.onload = function() {
            if (isFusion()) {
                Fusion = getFusionInstance();
                document.getElementById("viewer").innerHTML = "Viewer is: Fusion";
            } else {
                //Use our AJAX viewer event hooking example to listen for selection changes
                //http://trac.osgeo.org/mapguide/wiki/CodeSamples/JavaScript/AJAXViewerEventHooking
            
                //Timer variable
                var timer; 

                // This is our "watch" function. What we are doing here is 
                // repeatedly checking the mapInit value of the Map Frame. When
                // mapInit is true, then the map has been loaded.
                var watch = function() {
                    
                    // What we are doing here is attempting to access the mapInit
                    // variable of the Map frame. The reason the code is in a try-catch
                    // is because chances are that this code access the DOM
                    // of the map frame before its DOM has been initialized.
                    try {
                        var mapFrame = parent.parent.GetMapFrame();
                        if(mapFrame.mapInit) {
             
                            // Remove the timer so this watch function stops executing
                            clearInterval(timer);
                             
                            // Replace the OnSelectedFeatureChanged function with our own function.
                            // It is safe to do this now because the DOM for the map frame is fully initialized.
                            
                            // Store old function
                            origOnSelectedFeatureChanged = mapFrame.OnSelectedFeatureChanged;
                            // Now replace with our own.
                            mapFrame.OnSelectedFeatureChanged = onAjaxViewerSelectionChanged;
                            document.getElementById("viewer").innerHTML = "Viewer is: AJAX Viewer";
                        }
                    }
                    catch(e) {
                    }
                };
                
                // Start the "watching" process. We basically invoke the watch function 
                // every 200ms until the map has been loaded.
                timer = setInterval(watch, 200);
            }
        };
        
        </script>
    </head>
    <body>
        <h1>pgRouting Example</h1>
        <p>Enter the source and target IDs and hit "Calculate".</p>
        <p>You can get the source ID by selecting your road's starting point and inspecting the "source" property value</p>
        <p>You can get the target ID by selecting your road's ending point and inspecting the "target" property value</p>
        <p id="viewer"></p>
        <form action="shortest_path.php" method="post" onsubmit="return checkParameters()">
            <input type="hidden" name="SESSION" value="<?= $sessionId ?>" />
            <input type="hidden" name="MAPNAME" value="<?= $mapName ?>" />
            Source ID: <input type="text" name="SOURCE_ID" id="SOURCE_ID" value="" /><br/>
            Target ID: <input type="text" name="TARGET_ID" id="TARGET_ID" value="" /><br/>
            <input type="submit" id="btnCalculate" value="Calculate" />
        </form>
        <p id="status"></p>
    </body>
</html>